import React, { useRef } from 'react';
import ProTable, { ActionType } from '@ant-design/pro-table';
import request from 'umi-request';

export interface DataTable {
  toolBarRender?: object;           // 表格操作栏
  url?: boolean;                    // 表格请求地址
  columns?: object;                 // 表格列表显示配置
  rowKey?: string;                  // 表格key值
  headerTitle?: string              // 表格标题
  tableAlertOptionRender?: () => {};// 表格对选操作
  tableAlertRender?: () => {};      // 自定义批量操作工具栏左侧信息区域
  rowSelection?: object;            // 表格选择配置
  search?: object;                  // 搜索配置
  requestProcess?: ()=>{},          // 请求前参数处理  用于处理向时间间隔上传时参数重复问题
  onRow?: ()=>{},                   // 内容行操作
  onHeaderRow?: ()=>{},             // 标题行操作
}

const DataTable: React.FC<DataTable> =  (props) => {
  const actionRef = useRef<ActionType>();

  return (
    <ProTable
      columns={
        // 默认配置列都不出现在搜索中
        // v5中不再支持设置search为true，所以用searchbool代替
        props.columns.map((v) => {
          if(!v.searchbool){
            v.search = false;
          };
          return v
        })
      }
      actionRef={actionRef}
      request={async (params = {}) =>{
          params.pageNo = params.current;
          delete params.current;
          const msg = await request(props.url, {
            params: props.requestProcess?props.requestProcess(params):params,
          });
          if(msg.error.length > 0){
            return {
              success: false,
            };
          }else{
            return {
              data: msg.data.list,
              success: true,
              total: msg.data.totalCount,
            };
          }
        }
      }
      editable={{
        type: 'multiple',
      }}
      rowKey={props.rowKey || 'id'}
      search={{
        filterType: 'query',
        labelWidth: 'auto',
        defaultCollapsed: false,
        ...props.search,
      }}
      pagination={{
        pageSize: 10,
      }}
      scroll={{ x: 1300 }}
      dateFormatter="string"    // 时间转换格式
      headerTitle={props.headerTitle || '未知列表'}
      toolBarRender={() => props.toolBarRender || false}
      rowSelection={props.rowSelection || false}
      tableAlertRender={props.tableAlertRender || false}
      tableAlertOptionRender={props.tableAlertOptionRender || false}
      onRow={props.onRow}
      onHeaderRow={props.onHeaderRow}
      />
  );
};

export default DataTable;
