import React, { Component } from 'react';
import DataTable from '@/components/common/DataTable';
import {Button, Dropdown, Menu, Space, Table, DatePicker} from "antd";
import {EllipsisOutlined, PlusOutlined} from "@ant-design/icons";
import { TableDropdown } from '@ant-design/pro-table';

const { RangePicker } = DatePicker;

const menu = (
  <Menu>
    <Menu.Item key="1">1st item</Menu.Item>
    <Menu.Item key="2">2nd item</Menu.Item>
    <Menu.Item key="3">3rd item</Menu.Item>
  </Menu>
);

class Billing extends Component{
  constructor(props) {
    super(props);
    this.state = {
      columns: [
        {
          title: '合同编号',
          dataIndex: 'contractNo',
          width: 200,
          lock: 'left',
          searchbool: true,
        },
        {
          title: '订单编号',
          dataIndex: 'orderNo',
          width: 200,
        },
        {
          title: '客户名称',
          dataIndex: 'userName',
          render: text => {
            return text && text.length > 9 ? text.substr(0, 9) + '...' : text;
          },
        },
        {
          title: '订单部门',
          dataIndex: 'depName',
          width: 200,
        },
        {
          title: '下单时间',
          dataIndex: 'createDate',
          valueType: 'dateRange',
          searchbool: true,
        },
        {
          title: '合同签订时间',
          dataIndex: 'signDate',
          width: 200,
        },
        {
          title: '签单金额(万元)',
          dataIndex: 'totalAmount',
          width: 200,
          filters: true,
        },
        {
          title: '自定义筛选',
          key: 'direction',
          hideInTable: true,
          dataIndex: 'direction',
          searchbool: true,
          search: {
            transform: (v)=>{
              console.log(v)
              return v
            }
          },
          renderFormItem: (item, props) => {
            return (
              <RangePicker value={props.value} onPanelChange={props.onChange}/>
            );
          },
        },
        {
          title: '状态',
          dataIndex: 'state',
          initialValue: 'open',
          valueType: 'select',
          searchbool: true,
          filters: true,
          valueEnum: {
            all: {
              text: '全部',
              status: 'Default'
            },
            open: {
              text: '未解决',
              status: 'Error',
            },
            closed: {
              text: '已解决',
              status: 'Success',
            },
            processing: {
              text: '解决中',
              status: 'Processing',
            },
          },
        },
        {
          title: '操作',
          valueType: 'option',
          key: 'option',
          fixed: 'right',
          align: 'center',
          width: 150,
          render: (text, record, _, action) => [
            <a
              key="editable"
              onClick={() => {}}
            >
              开票
            </a>,
            <a target="_blank" rel="noopener noreferrer" key="view">
              结项
            </a>,
            <TableDropdown
              key="actionGroup"
              onSelect={(v) => {
                //操作
                console.log(v)
              }}
              menus={[
                { key: 'copy', name: '复制' },
                { key: 'delete', name: '删除' },
              ]}
            />,
          ],
        },
      ]
    }
  }

  componentDidMount() {

  }

  render() {
    return (
      <div>
        <DataTable
          url='/api/admin/newOrder/orderNewList'
          rowKey='orderNo'
          columns={this.state.columns}
          rowSelection={{
            type: 'radio',
            selections: [Table.SELECTION_ALL, Table.SELECTION_INVERT],
          }}
          requestProcess={(v)=>{
            if(v && v.createDate){
              v.starTime = v.createDate[0];
              v.endTime = v.createDate[1];
              delete v.createDate;
            }
            return v;
          }}
          onRow={record => {
            return {
              onClick: (event) => {
                console.log(record,event);
              }, // 点击行
            };
          }}
          onHeaderRow={column => {
            return {
              onClick: () => {}, // 点击表头行
            };
          }}
          toolBarRender={[
            <Button key="button" icon={<PlusOutlined />} type="primary">
              新建
            </Button>,
            <Dropdown key="menu" overlay={menu}>
              <Button>
                <EllipsisOutlined />
              </Button>
            </Dropdown>,
          ]}
          tableAlertRender={({ selectedRowKeys, selectedRows, onCleanSelected }) => (
            <Space size={24}>
              <span>
                已选 {selectedRowKeys.length} 项
                <a style={{ marginLeft: 8 }} onClick={onCleanSelected}>
                  取消选择
                </a>
              </span>
                  <span>{`签单金额: ${selectedRows.reduce(
                    (pre, item) => pre + item.totalAmount,
                    0,
                  )} 万`}</span>
            </Space>
          )}
          tableAlertOptionRender={({ selectedRowKeys, selectedRows, onCleanSelected }) => {
            return (
              <Space size={16}>
                <a>查看开票记录</a>
                <a>查看催款详情</a>
                <a>查看项目进度</a>
              </Space>
            );
          }}
        />
      </div>
    );
  }
}

export default Billing;
